@@ -35,6 +35,7 @@ static gchar *contributors[] = {
 	"Christopher Blizzard",
 	N_("Jerome Bolliet"),
 	"Andreas Bolsch",
+	"Dave Bordoley",
 	"Dario Bressanini",
 	"Emmanuel Briot",
 	"Stephen Browne",
@@ -59,7 +60,11 @@ static gchar *contributors[] = {
 	"Jeremy Collins",
 	"Rusty Conover",
 	"Alan Cox",
+	"Dennis Cranston",
 	"Mark Crichton",
+	/* if you encoding allows it, use eacute (U00E9) for the two
+	 * 'e' of 'Frederic' */
+	N_("Frederic Crozat"),
 	"Andreas Czechanowski",
 	"Dan Damian",
 	"Phil Dawes",
@@ -76,6 +81,7 @@ static gchar *contributors[] = {
 	"Arturo Espinosa",
 	"Gus Estrella",
 	"David Etherton",
+	"Larry Ewing",
 	"Marc Ewing",
 	/* if your encoding allows it, use odoubleacute (U0151) for the 'o'
 	 * of 'Gergo' and use Eacute (U00C9) for the 'E' of 'Erdi' */
@@ -89,6 +95,7 @@ static gchar *contributors[] = {
 	N_("Raul Perusquia Flores"),
 	"Lawrence Foard",
 	"Glynn Foster",
+	"Ben FrantzDale",
 	"Jeff Freedman",
 	"David Abilleira Freijeiro",
 	"Nat Friedman",
@@ -116,6 +123,7 @@ static gchar *contributors[] = {
 	"Lars Hamann",
 	"Michael Hanni",
 	"Raja R Harinath",
+	"Heath Harrelson",
 	"Peter Hawkins",
 	"Scott Heavner",
 	"James Henstridge",
@@ -254,6 +262,7 @@ static gchar *contributors[] = {
 	N_("Kazuhiro Sasayama"),
 	"Carsten Schaar",
 	"Christian Schaller",
+	"Wayne Schuller",
 	"Franck Schneider",
 	"Ingo Schneider",
 	"Bernd Schroeder",
@@ -277,6 +286,7 @@ static gchar *contributors[] = {
 	N_("The Squeaky Rubber Gnome"),
 	"Maciej Stachowiak",
 	"Stalyn",
+	"Jeffrey Stedfast",
 	"Jakub Steiner",
 	"Ben Stern",
 	"Micah Stetson",
@@ -292,15 +302,18 @@ static gchar *contributors[] = {
 	"Christoph Toshok",
 	"Tom Tromey",
 	"Jon Trowbridge",
+	"Vincent Untz",
 	N_("Manish Vachharajani"),
 	N_("Neil Vachharajani"),
 	"Daniel Veillard",
 	"Vendu",
 	"Andrew Veliath",
+	"Luis Villa",
 	"Marius Vollmer",
 	"Shawn Wagner",
-	"Matthias Warkus",
 	N_("Wanda the GNOME Fish"),
+	"Matthias Warkus",
+	"Jeff Waugh",
 	"Bruno Widmann",
 	"Robert Wilhelm",
 	"Sebastian Wilhelmi",
