@@ -174,18 +174,23 @@ enum {
 #define TYPE_STRING "GnomeDitemEdit:TypeString"
 
 static void
-add_menuitem (GtkWidget *menu, const char *str, const char *label,
-	      const char *select, GtkWidget **selected)
+add_menuitem (GtkWidget   *menu,
+	      const char  *str,
+	      const char  *label,
+	      const char  *select,
+	      GtkWidget  **selected)
 {
-	GtkWidget *item = gtk_menu_item_new_with_label (label);
+	GtkWidget *item;
+
+	item = gtk_menu_item_new_with_label (label);
 	gtk_widget_show (item);
+
 	g_object_set_data_full (G_OBJECT (item), TYPE_STRING,
-				g_strdup (str),
-				(GDestroyNotify)g_free);
+				g_strdup (str), (GDestroyNotify) g_free);
+
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
-	if (select != NULL &&
-	    strcmp (str, select) == 0)
+	if (selected && select && !strcmp (str, select))
 		*selected = item;
 }
 
@@ -225,14 +230,22 @@ setup_option (GnomeDItemEdit *dee,
 		break;
 	}
 
-	if (select != NULL &&
-	    selected == NULL)
+	if (select && selected)
 		add_menuitem (menu, select, _(select), select, &selected);
 
-	if (selected != NULL)
-		gtk_menu_item_activate (GTK_MENU_ITEM (selected));
-
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (dee->_priv->type_option), menu);
+
+	if (selected) {
+		GList *children;
+		int    pos;
+
+		children = gtk_container_get_children (GTK_CONTAINER (menu));
+		pos = g_list_index (children, selected);
+		g_list_free (children);	
+
+		gtk_option_menu_set_history (GTK_OPTION_MENU (dee->_priv->type_option), pos);
+	}
+
 }
 
 static const char *
@@ -307,7 +320,6 @@ type_option_changed (GnomeDItemEdit *dee)
 static GtkWidget *
 make_easy_page (GnomeDItemEdit *dee)
 {
-	GtkWidget *frame;
 	GtkWidget *table;
 	GtkWidget *label;
 	GtkWidget *entry;
@@ -317,17 +329,11 @@ make_easy_page (GnomeDItemEdit *dee)
 	GtkWidget *icon_entry;
 	GtkWidget *check_button;
 
-        frame = gtk_frame_new (NULL);
-        gtk_container_set_border_width (
-			GTK_CONTAINER (frame), GNOME_PAD_SMALL);
-
         table = gtk_table_new (5, 2, FALSE);
         gtk_container_set_border_width (GTK_CONTAINER (table), GNOME_PAD_SMALL);
         gtk_table_set_row_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
         gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
 
-        gtk_container_add (GTK_CONTAINER (frame), table);
-
 	/* Name */
 	label = label_new (_("Name:"));
 	table_attach_label (GTK_TABLE (table), label, 0, 1, 0, 1);
@@ -442,7 +448,7 @@ make_easy_page (GnomeDItemEdit *dee)
         gtk_container_add (GTK_CONTAINER (align), check_button);
         dee->_priv->terminal_button = check_button;
 
-	return frame;
+	return table;
 }
 
 static GtkTreeIter*
@@ -524,12 +530,12 @@ translations_add (GtkWidget      *button,
 	GtkTreeView  *tree;
 	GtkTreeModel *model;
 	GtkTreeIter   iter;
-	const GList  *langs;
 	const char   *tmp;
 	const char   *name;
 	const char   *generic_name;
 	const char   *comment;
 	char         *lang;
+	const char   *locale;
 	gboolean      ret;
 
 	tmp     = gtk_entry_get_text (GTK_ENTRY (dee->_priv->transl_lang_entry));
@@ -550,9 +556,8 @@ translations_add (GtkWidget      *button,
 	 * If we are editing the current language, change the name and
 	 * comment entries on the easy page as well.
 	 */
-	langs = gnome_i18n_get_language_list ("LC_ALL");
-	tmp = langs ? langs->data : NULL;
-	if ((tmp && !strcmp (tmp, lang)) || (!tmp && !strcmp (tmp, "C"))) {
+	locale = gnome_desktop_item_get_attr_locale (dee->_priv->ditem, "Name");
+	if ((locale && !strcmp (locale, lang)) || (!locale && !strcmp (lang, "C"))) {
 		gtk_entry_set_text (
 			GTK_ENTRY (dee->_priv->name_entry), name);
 		gtk_entry_set_text (
@@ -578,7 +583,7 @@ translations_add (GtkWidget      *button,
 				3, comment,
 				-1);
 
-			g_signal_emit (dee, ditem_edit_signals [CHANGED], 0);
+			gnome_ditem_edit_changed (dee);
 
 			g_free (string);
 			g_free (lang);
@@ -609,7 +614,7 @@ translations_add (GtkWidget      *button,
 	gtk_editable_delete_text (
 		GTK_EDITABLE (dee->_priv->transl_comment_entry), 0, -1);
 
-	g_signal_emit (dee, ditem_edit_signals [CHANGED], 0);
+	gnome_ditem_edit_changed (dee);
 
 	g_free (lang);
 }
@@ -630,8 +635,8 @@ translations_remove (GtkWidget      *button,
                return;
 
         gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
-
-        g_signal_emit (G_OBJECT(dee), ditem_edit_signals [CHANGED], 0);
+	
+	gnome_ditem_edit_changed (dee);
 }
 
 static GtkWidget *
@@ -684,7 +689,6 @@ setup_translations_list (GnomeDItemEdit *dee)
 static GtkWidget *
 make_advanced_page (GnomeDItemEdit *dee)
 {
-	GtkWidget *frame;
 	GtkWidget *vbox;
 	GtkWidget *table;
 	GtkWidget *label;
@@ -692,19 +696,15 @@ make_advanced_page (GnomeDItemEdit *dee)
 	GtkWidget *button;
 	GtkWidget *box;
 
-        frame = gtk_frame_new (NULL);
-        gtk_container_set_border_width (
-			GTK_CONTAINER (frame), GNOME_PAD_SMALL);
-
-	vbox = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
-        gtk_container_add (GTK_CONTAINER (frame), vbox);
+	vbox = gtk_vbox_new (FALSE, 5);
+        gtk_container_set_border_width (GTK_CONTAINER (vbox), GNOME_PAD_SMALL);
 
         table = gtk_table_new (2, 2, FALSE);
         gtk_container_set_border_width (GTK_CONTAINER (table), GNOME_PAD_SMALL);
         gtk_table_set_row_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
         gtk_table_set_col_spacings (GTK_TABLE (table), GNOME_PAD_SMALL);
 
-        gtk_box_pack_start (GTK_BOX (vbox), table, TRUE, TRUE, 0);
+        gtk_box_pack_start (GTK_BOX (vbox), table, FALSE, FALSE, 0);
 
 	label = label_new (_("Try this before using:"));
 	table_attach_label (GTK_TABLE (table), label, 0, 1, 0, 1);
@@ -732,17 +732,22 @@ make_advanced_page (GnomeDItemEdit *dee)
 
 	label = gtk_label_new (_("Name/Comment translations:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 
 	dee->_priv->translations = setup_translations_list (dee);
 
 	box = gtk_scrolled_window_new (NULL, NULL);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (box),
+					     GTK_SHADOW_IN);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (box),
+					GTK_POLICY_AUTOMATIC,
+					GTK_POLICY_AUTOMATIC);
 	gtk_widget_set_size_request (box, 0, 120);
 	gtk_container_add (GTK_CONTAINER (box), dee->_priv->translations);
 	gtk_box_pack_start (GTK_BOX (vbox), box, TRUE, TRUE, 0);
 
 	box = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
-	gtk_box_pack_start (GTK_BOX (vbox), box, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), box, FALSE, FALSE, 0);
 
 	entry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (box), entry, TRUE, TRUE, 0);
@@ -793,7 +798,7 @@ make_advanced_page (GnomeDItemEdit *dee)
 	set_tooltip (dee, GTK_WIDGET(button),
 		    _("Remove Name/Comment Translation"));
   
-	return frame;
+	return vbox;
 }
 
 static void
@@ -967,7 +972,7 @@ gnome_ditem_edit_sync_display (GnomeDItemEdit *dee)
 	gnome_icon_entry_set_filename (GNOME_ICON_ENTRY (dee->_priv->icon_entry), tmpstr);
 	g_free (tmpstr);
 
-        cs = gnome_desktop_item_get_string (ditem, "DocPath"); /* FIXME check name */
+        cs = gnome_desktop_item_get_string (ditem, "X-GNOME-DocPath");
         gtk_entry_set_text (GTK_ENTRY (dee->_priv->doc_entry), cs ? cs : "");
 
         gtk_toggle_button_set_active
@@ -979,22 +984,29 @@ gnome_ditem_edit_sync_display (GnomeDItemEdit *dee)
         model = gtk_tree_view_get_model (GTK_TREE_VIEW (dee->_priv->translations));
         gtk_list_store_clear (GTK_LIST_STORE (model));
         i18n_list = gnome_desktop_item_get_languages (ditem, NULL);
-        for (li = i18n_list; li != NULL; li = li->next) {
+	for (li = i18n_list; li != NULL; li = li->next) {
                 const char *name, *comment, *generic_name;
                 const char *lang = li->data;
+
                 name = gnome_desktop_item_get_localestring_lang
 			(ditem, GNOME_DESKTOP_ITEM_NAME, lang);
                 generic_name = gnome_desktop_item_get_localestring_lang
 			(ditem, GNOME_DESKTOP_ITEM_GENERIC_NAME, lang);
                 comment = gnome_desktop_item_get_localestring_lang
 			(ditem, GNOME_DESKTOP_ITEM_COMMENT, lang);
-                gtk_list_store_append (GTK_LIST_STORE(model), &iter);
-                gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-				    0, lang ? lang : "",
-				    1, name ? name : "",
-				    2, generic_name ? generic_name : "",
-				    3, comment ? comment : "",
-				    -1);
+                
+		/* only include a language in the list if it 
+		 * has a useful translation
+		 */
+		if (name || generic_name || comment) {
+			gtk_list_store_append (GTK_LIST_STORE(model), &iter);
+			gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+					    0, lang ? lang : "",
+					    1, name ? name : "",
+					    2, generic_name ? generic_name : "",
+					    3, comment ? comment : "",
+					    -1);
+		}
         }
         g_list_free (i18n_list);
 
